<div id="mkdocs-encrypted-content" style="display:none">{{ ciphertext_bundle }}</div>
<div id="mkdocs-decrypted-content">
    <form id="mkdocs-decrypt-form">
        <h1>{{ summary }}</h1>
        {% if encryption_info_message %}<p>{{ encryption_info_message }}</p>{% endif %}
        <input{% if input_class %} class="{{ input_class }}"{% endif %} type="password" id="mkdocs-content-password" placeholder="{{ placeholder }}" />
        {% if password_button %}<button{% if button_class %} class="{{ button_class }}"{% endif %} id="mkdocs-decrypt-button">{{ password_button_text }}</button>{% endif %}
        <p id="mkdocs-decrypt-msg"></p>
    </form>
</div>

<script type="text/javascript">
var encryptcontent_path = "{{ encryptcontent_path }}";
</script>
{% for library in js_libraries %}
<script type="text/javascript" src="{{ library }}"></script>
{%- endfor %}
<script type="text/javascript" src="{{ base_path }}assets/javascripts/decrypt-contents.js" defer></script>

